@@ -5,7 +5,7 @@ use crate::{
     main_loop::{self, CredentialsProvider},
     utils::Backoff,
 };
-use color_eyre::{eyre::eyre, Section};
+use color_eyre::{Section, eyre::eyre};
 use futures::StreamExt as _;
 use librespot_playback::{
     audio_backend::{self},
@@ -25,26 +25,48 @@ pub(crate) fn initial_state(
             }
             #[cfg(feature = "alsa_backend")]
             config::VolumeController::Alsa | config::VolumeController::AlsaLinear => {
-                let audio_device = config.audio_device.clone();
-                let control_device = config.alsa_config.control.clone();
-                let mixer = config.alsa_config.mixer.clone();
+                let device = config
+                    .alsa_config
+                    .mixer
+                    .as_deref()
+                    .or(config.audio_device.as_deref())
+                    .unwrap_or("default")
+                    .to_string();
+                let control = config
+                    .alsa_config
+                    .control
+                    .as_deref()
+                    .unwrap_or("Master")
+                    .to_string();
                 info!("Using alsa volume controller.");
-                let linear = matches!(
+                use librespot_playback::config::VolumeCtrl;
+                let volume_ctrl = if matches!(
                     config.volume_controller,
                     config::VolumeController::AlsaLinear
-                );
-                Arc::new(alsa_mixer::AlsaMixer {
-                    device: control_device
-                        .clone()
-                        .or_else(|| audio_device.clone())
-                        .unwrap_or_else(|| "default".to_string()),
-                    mixer: mixer.clone().unwrap_or_else(|| "Master".to_string()),
-                    linear_scaling: linear,
-                })
+                ) {
+                    VolumeCtrl::Linear
+                } else {
+                    VolumeCtrl::Log(0.0) /* this value is ignored */
+                };
+                Arc::new(alsa_mixer::AlsaMixer::open(MixerConfig {
+                    device,
+                    control,
+                    index: 0,
+                    volume_ctrl,
+                }).with_suggestion(|| {
+                    match alsa_mixer::get_available_controls() {
+                        Err(err) => format!("there are no controls available, maybe check that alsa is available: {err}"),
+                        Ok(controls) => {
+                            format!("maybe try one of the following as 'mixer':{}", controls.filter_map(|hint| hint.name.map(|name| format!("\n- {name}"))).collect::<String>())
+                        }
+                    }
+                })?)
             }
             _ => {
                 info!("Using software volume controller.");
-                Arc::new(mixer::softmixer::SoftMixer::open(MixerConfig::default()))
+                let mixer = mixer::softmixer::SoftMixer::open(MixerConfig::default())
+                    .expect("SoftMixer::open never returns an Error");
+                Arc::new(mixer)
             }
         }
     };
@@ -53,8 +75,6 @@ pub(crate) fn initial_state(
     let session_config = config.session_config;
     let backend = config.backend.clone();
 
-    let has_volume_ctrl = !matches!(config.volume_controller, config::VolumeController::None);
-
     let zeroconf_port = config.zeroconf_port.unwrap_or(0);
 
     let creds = if let Some(creds) = config.oauth_cache.as_ref().and_then(|c| c.credentials()) {
@@ -116,9 +136,9 @@ pub(crate) fn initial_state(
         (None, Some(creds)) => CredentialsProvider::CredentialsOnly(creds),
         (None, None) => {
             return Err(
-                eyre!("Discovery unavailable and no credentials found.").with_suggestion(|| {
-                    "Try enabling discovery or logging in first with `spotifyd authenticate`."
-                }),
+                eyre!("Discovery unavailable and no credentials found.").with_suggestion(
+                    || "Try enabling discovery or logging in first with `spotifyd authenticate`.",
+                ),
             );
         }
     };
@@ -135,7 +155,7 @@ pub(crate) fn initial_state(
         player_config,
         backend,
         initial_volume: config.initial_volume,
-        has_volume_ctrl,
+        disable_volume: false,
         shell: config.shell,
         device_type: config.device_type,
         device_name: config.device_name,
